local GT = AceLibrary("Gratuity-2.0")
local Deformat = AceLibrary("Deformat-2.0")		
		
local tierSets = {}
local armorSets = {
	DRUID = { "Nordrassil Raiment", "Nordrassil Regalia", },
	MAGE = { "Tirisfal Armor", },
	PALADIN = { "Justicar Armor", "Justicar Battlegear", "Crystalforge Raiment", },
	PRIEST = { "Hallowed Raiment", "Incarnate Regalia", "Incarnate Raiment", },
	SHAMAN = { "Tidefury Raiment", "Cataclysm Raiment", "The Ten Storms", },
	WARLOCK = { "Oblivion Raiment", "Voidheart Raiment", "Corruptor Raiment", "Plagueheart Raiment" },
}

local armorSetsFR = {
	DRUID = { "Grande Tenue de Nordrassil", "Tenue de Parade de Nordrassil", },
	MAGE = { "Tenue de Parade de Tirisfal", },
	PALADIN = { "Armure de Justicier", "Tenue de combat de Justicier", "Grande Tenue de Cristalforge", },
	PRIEST = { "Grande Tenue B\195\169nie", "Tenue de Parade des Incarn\195\169s", "Grande Tenue des Incarn\195\169s", },
	SHAMAN = { "Grande Tenue du Mascaret", "Grande Tenue du Cataclysme", "Les Dix temp\195\170tes", },
	WARLOCK = { "Grande Tenue de l'oubli", "Grande Tenue du Coeur-du-Vide", "Grande Tenue de Corrupteur", "Grande Tenue de Pestecoeur", },
}

local _, englishClass = UnitClass("player")

function DrDamage:ItemSets()

	local setTable
	
	if GetLocale() == "enUS" or GetLocale() == "enGB" then
		setTable = armorSets[englishClass]
	elseif GetLocale() == "frFR" then
		setTable = armorSetsFR[englishClass]
	end
	
	if not setTable then
		do return end
	end

	for k in ipairs( tierSets ) do
		tierSets[k] = nil
	end
	
	for i = 1, 12 do
		local link = GetInventoryItemLink( "player", i )
		if link then 
			GT:SetHyperlink( link )
			for j = 2, GT:NumLines() do
				setName, setAmount = Deformat(GT:GetLine(j), ITEM_SET_NAME)
				if setName then
					for tier, set in ipairs( setTable ) do
						if setName == set then
							tierSets[tier] = setAmount
						end
					end					
				end
			end
		end
	end
	
	for i = 1, 4 do
		if not tierSets[i] then
			tierSets[i] = 0
		end
	end
end

function DrDamage:SetBonuses( spellName, eDuration, finalMod, dmgM, castTime, chainFactor )

	local b1, b2, b3, b4 = unpack( tierSets )

	if englishClass == "DRUID" then
		if b1 then
			if b1 >= 2 then
				if spellName == "Regrowth" then
					eDuration = eDuration + 6
				end

				if b1 >= 4 then
					if spellName == "Lifebloom" then
						finalMod = finalMod + 150
					end
				end
			end
		end
		--[[ TODO:
		if b2 then
			Nordrassil Regalia (0/5)
			(4) Set: Increases your Starfire damage against targets afflicted with Moonfire or Insect Swarm by 10%.	
		end
		--]]
	elseif englishClass == "MAGE" then
		if b1 then
			if b1 >= 2 then
				if spellName == "Arcane Blast" then
					dmgM = dmgM * 1.2
				end
			end
		end
	elseif englishClass == "PALADIN" then
		if b1 then
			if b1 >= 4 then
				if spellName == "Holy Shield" then
					dmgM = dmgM * 1.15
				end
			end
		end
		if b2 then
			--TODO: 2: Increases the damage bonus of your Judgement of the Crusader by 15%.
			if b2 >= 4 then
				if spellName == "Seal of Command" then
					dmgM = dmgM * 1.1
				end
			end
		end
		if b3 then
			if b3 >= 4 then
				if spellName == "Holy Light" then
					castTime = castTime - 0.2
				end
			end
		end
	elseif englishClass == "PRIEST" then
		if b1 then
			if b1 >= 4 then
				if spellName == "Prayer of Mending" then
					finalMod = finalMod + 100
				end
			end
		end
		if b2 then
			if b2 >=4 then
				if spellName == "Smite" or spellName == "Mind Flay" then
					dmgM = dmgM * 1.05
				end
			end
		end
		--[[
		if b3 then
			if b2 >= 2 then
				if spellName == "Prayer of Healing" then
					2: Your Prayer of Healing spell now also causes an additional 150 healing over 9 seconds.
				end
			end
		end
		--]]

	elseif englishClass == "SHAMAN" then
		if b1 then
			if b1 >= 2 then
				if spellName == "Chain Lightning" then
					chainFactor = chainFactor + 0.13
				end
			end
		end
		if b2 then
			if b2 >= 4 then
				if spellName == "Healing Wave" then
					castTime = castTime - 0.25
				end
			end
		end
		if b3 then
			if b3 >= 3 then
				if spellName == "Chain Heal" then
					chainFactor = chainFactor + 0.3
				end
			end
		end
	elseif englishClass == "WARLOCK" then
		if b1 then
			if b1 >= 4 then
				if spellName == "Seed of Corruption" then
					finalMod = finalMod + 180
				end
			end
		end
		if b2 then
			if b2 >= 4 then
				if spellName == "Corruption" or spellName == "Immolate" then
					eDuration = eDuration + 3
				end
			end
		end
		if b4 then
			if b4 >= 4 then
				if spellName == "Corruption" then
					dmgM = dmgM * 1.12
				end
			end
		end
	end
	
	return eDuration, finalMod, dmgM, castTime, chainFactor
end